@@ -185,8 +185,8 @@ class FrescoApp(RouteCollection):
         return self.view(self, self.request_class(environ))(environ,
                                                             start_response)
 
-    def _make_wsgi_app(self):
-        app = self._raw_wsgi_app
+    def _make_wsgi_app(self, app=None):
+        app = app or self._raw_wsgi_app
         for middleware, args, kwargs in self._middleware:
             app = middleware(app, *args, **kwargs)
         for middleware in self.core_middleware:
@@ -313,7 +313,22 @@ class FrescoApp(RouteCollection):
 
         environ.update(env_overrides)
         context.push(request=self.request_class(environ), app=self)
+
+        def _fakewsgiapp(environ, start_response):
+            start_response('200 OK', [])
+            yield b''
+        _fakewsgiapp = self._make_wsgi_app(_fakewsgiapp)
+
+        # Invoke a fake wsgi app wrapped in all middleware layers. This
+        # executes any middleware, which may have side effects which are
+        # expected downstream (eg setting environ keys)
+        wsgi_iter = _fakewsgiapp(environ, lambda *a, **kw: None)
+        next(wsgi_iter)
         yield context
+
+        # Exhaust the iterator and close up
+        list(wsgi_iter)
+        getattr(wsgi_iter, 'close', lambda: None)()
         context.pop()
 
 
