@@ -87,7 +87,7 @@ def extract_requestargs(requesttype, **argspec):
                                      for cast, v in zip(cycle(type_fn), value)]
                         else:
                             value = type_fn(value)
-                    except ValueError, e:
+                    except ValueError as e:
                         if name in defaults and not strict_checking:
                             value = defaults[name]
                         else:
@@ -109,10 +109,11 @@ def extract_requestargs(requesttype, **argspec):
 
 extract_getargs = partial(extract_requestargs, GET)
 extract_postargs = partial(extract_requestargs, POST)
-extract_getargs.__doc__ = """
-    Extract function arguments from request parameters. See extract_getargs for details.
-"""
-extract_getargs.__doc__ = """
+extract_getargs.__doc__ = """\
+        Extract function arguments from request parameters. See extract_getargs
+        for details.
+        """
+extract_getargs.__doc__ = """\
     Extract function arguments from request parameters
 
     Synopsis::
@@ -123,8 +124,8 @@ extract_getargs.__doc__ = """
         >>> app = FrescoApp()
         >>> @app.route('/', GET)
         ... @extract_getargs(GET, id=int)
-        ... def my_app(request, id):
-        ...     return Response([u'Got id %d' % (id,)])
+        ... def my_app(id):
+        ...     return Response(['Got id %d' % (id,)])
         ...
         >>> print TestAgent(app).get('/?id=2')
         200 OK\r
@@ -153,8 +154,8 @@ extract_getargs.__doc__ = """
         >>> app = FrescoApp()
         >>> @app.route('/', GET)
         ... @extract_getargs(actions=[unicode])
-        ... def my_app(request, id):
-        ...     return Response([u'Got id %d' % (id,)])
+        ... def my_app(id):
+        ...     return Response(['Got id %d' % (id,)])
         ...
         >>> print TestAgent(app).get('/')
         Traceback (most recent call last):
@@ -166,8 +167,8 @@ extract_getargs.__doc__ = """
         >>> app = FrescoApp()
         >>> @app.route('/', GET)
         ... @extract_getargs(actions=[unicode])
-        ... def my_app(request, id=1):
-        ...     return Response([u'Got id %d' % (id,)])
+        ... def my_app(id=1):
+        ...     return Response(['Got id %d' % (id,)])
         ...
         >>> print TestAgent(app).get('/')
         200 OK\r
@@ -183,9 +184,9 @@ extract_getargs.__doc__ = """
         >>> app = FrescoApp()
         >>> @app.route('/', GET)
         ... @extract_getargs(actions=[unicode])
-        ... def my_app(request, actions):
+        ... def my_app(actions):
         ...     return Response([
-        ...         u', '.join(actions)
+        ...         ', '.join(actions)
         ...     ])
         ...
         >>> print TestAgent(app).get('/?actions=up;actions=up;actions=and+away%21')
