@@ -166,11 +166,6 @@ HEADER_NAMES = {
 def encoder(stream, charset):
     r"""\
     Encode a response iterator using the given character set.
-
-    Synopsis::
-
-        >>> list(encoder(['Price \u00a3200'], 'latin1'))
-        [b'Price \xa3200']
     """
     if charset is None:
         charset = 'UTF-8'
@@ -644,17 +639,9 @@ class Response(object):
     @classmethod
     def request_entity_too_large(cls, request=None):
         """\
-        Return an HTTP Request Entity Too Large response (413).
+        Return an HTTP Request Entity Too Large response (413)::
 
-        Example usage::
-
-            >>> from flea import TestAgent
             >>> response = Response.request_entity_too_large()
-            >>> print TestAgent(response).get('/', check_status=False)
-            413 Request Entity Too Large\r
-            Content-Type: text/html; charset=UTF-8\r
-            \r
-            <html><body><h1>Request Entity Too Large</h1></body></html>
 
         """
         return cls(
