@@ -2,13 +2,12 @@ import re
 import sys
 from collections import namedtuple
 from functools import partial
-from itertools import cycle
-from operator import attrgetter, itemgetter, methodcaller
 
 from fresco.compat import string_types
-from fresco.exceptions import BadRequest, ResponseException
+from fresco.exceptions import ResponseException
 from fresco.response import Response
 from fresco.requestcontext import context
+from fresco.routeargs import RouteKwarg
 from fresco.util.urls import join_path
 
 RFC2518_METHODS = \
@@ -39,8 +38,7 @@ ALL_METHODS = HTTP_METHODS = (RFC2518_METHODS + RFC2616_METHODS +
                               RFC5323_METHODS + RFC5789_METHODS)
 
 __all__ = ('ALL_METHODS', 'Pattern', 'Route', 'DelegateRoute',
-           'RouteCollection', 'FormArg', 'QueryArg',
-           'CookieArg', 'routefor')
+           'RouteCollection', 'routefor')
 
 __all__ += tuple(method.replace('-', '_') for method in ALL_METHODS)
 
@@ -506,7 +504,7 @@ class Route(object):
     pattern_class = ExtensiblePattern
 
     def __init__(self, pattern, methods, view, view_kwargs=None,
-                 name=None, predicate=None, decorators=None,
+                 view_args=None, name=None, predicate=None, decorators=None,
                  **kwargs):
 
         """
@@ -516,6 +514,7 @@ class Route(object):
         :param view:        The view function.
         :param view_kwargs: A dictionary of default keyword arguments to pass
                             to the view callable
+        :param view_args:   Positional arguments to pass to the view callable
         :param name:        A name that can later be used to retrieve the route
                             for URL generation
         :param predicate:   A callable that is used to decide whether to match
@@ -541,24 +540,29 @@ class Route(object):
 
         Views may often be assigned to multiple routes, for example::
 
-            Route('/image', display_image, size=(1024, 768))
-            Route('/thumbnail', display_image, size=(75, 75))
+            >>> def display_image(size):
+            ...     return Response(['image data...'])
+            ...
+            >>> from fresco import FrescoApp
+            >>> app = FrescoApp()
+            >>> app.route('/image', display_image, size=(1024, 768))
+            >>> app.route('/thumbnail', display_image, size=(75, 75))
 
         If you generate a URL for the view function ``display_image``, the
         the first declared route will always win, in this case::
 
-            >>> urlfor(display_image)  # doctest: +SKIP
+            >>> app.urlfor(display_image)
             'http://localhost/image'
 
         To generate URLs for the thumbnail route in this example, you must
         explicity assign names::
 
-            Route('/image', display_image, name='image', ...)
-            Route('/thumbnail', display_image, name='image-thumbnail', ...)
+            >>> app.route('/image', display_image, name='image')
+            >>> app.route('/thumbnail', display_image, name='image-thumbnail')
 
-            >> urlfor('image')  # doctest: +SKIP
+            >>> app.urlfor('image')
             'http://localhost/image'
-            >> urlfor('image-thumbnail')  # doctest: +SKIP
+            >>> app.urlfor('image-thumbnail')
             'http://localhost/thumbnail'
 
         """
@@ -600,6 +604,7 @@ class Route(object):
             if default is not _marker:
                 self.routed_args_default[k] = default
 
+        self.view_args = tuple(view_args or tuple())
         self.view_kwargs = dict(view_kwargs or {}, **kwargs)
         for argname, arg in self.view_kwargs.items():
             if isinstance(arg, RouteKwarg):
@@ -952,7 +957,7 @@ class RouteCollection(object):
         """
         Route requests to ``path`` to the given WSGI application
         """
-
+        # XXX: need to shift path_info to script_name
         from fresco import context
 
         def fresco_wsgi_view():
@@ -1033,181 +1038,3 @@ class DelegateRoute(Route):
 
     def _static_routecollectionfactory(self, *args, **kwargs):
         return self.getview()
-
-
-class RouteKwarg(object):
-    """
-    RouteKwarg objects can be used as keyword arguments in a route definition.
-    RouteKwargs can extract information from the request and make it available
-    to the view.
-
-    For example a RouteKwarg could be developed that reads information from the
-    request cookie::
-
-        Route('/', GET, affiliate=CookieArg())
-
-    A naive implementation ``CookieArg`` could look like this::
-
-        class CookieArg(RouteKwarg):
-
-            def __call__(self, request):
-                try:
-                    return request.cookies[self.name].value
-                except KeyError,
-                    return None
-
-    When the route is constructed the RouteKwarg's ``configure`` method will
-    be called with the Route object and the keyword name.
-
-    At every request, the RouteKwarg instance will be called and expected to
-    supply the value for its argument.
-    """
-
-    route = None
-    name = None
-
-    def configure(self, route, name):
-        self.route = route
-        self.name = name
-
-    def __call__(self, request):
-        return None
-
-
-class RequestArg(RouteKwarg):
-    """
-    Extract a view keyword argument from the request object.
-
-    """
-    query = attrgetter('query')
-    form = attrgetter('form')
-    cookies = attrgetter('cookies')
-    session = attrgetter('session')
-
-    #: Source for the request variable
-    source = form
-
-    #: Exceptions that signal the converter could not do its job due to invalid
-    #: input
-    converter_exceptions = (ValueError, TypeError)
-
-    def __init__(self, converter=None, key=None,
-                 default=_marker, exception=BadRequest):
-
-        self.formkey = key
-        self.default = default
-        self.required = default is _marker
-        self.exception = exception
-        self.is_list = isinstance(converter, list)
-        if self.is_list:
-            self.converter = lambda vs: [c(v)
-                                         for c, v in zip(cycle(converter), vs)]
-        else:
-            self.converter = converter
-
-    def configure(self, route, name):
-        if self.formkey is None:
-            self.formkey = name
-        if self.is_list:
-            self.getter = methodcaller('getlist', self.formkey)
-        else:
-            self.getter = itemgetter(self.formkey)
-
-    def __call__(self, request):
-        try:
-            value = self.getter(self.source(request))
-        except KeyError:
-            if self.required:
-                raise self.exception('No value provided for %s' %
-                                     (self.formkey,))
-            return self.default
-
-        try:
-            if self.converter is not None:
-                value = self.converter(value)
-        except self.converter_exceptions:
-            raise self.exception('%r is not a valid value for %s' %
-                                 (value, self.formkey,))
-
-        return value
-
-
-class CookieArg(RequestArg):
-    """\
-    Extract a view keyword argument from ``request.cookies``.
-
-    Example::
-
-        @app.route('/', GET, message=CookieArg(key='msg', default=None))
-        def view(message):
-            return Response([message])
-    """
-    source = RequestArg.cookies
-
-    def getter(self, cookies):
-        if self.is_list:
-            return [c.value for c in cookies.getlist(self.formkey)]
-        else:
-            return cookies[self.formkey].value
-
-    def configure(self, route, name):
-        if self.formkey is None:
-            self.formkey = name
-
-
-class QueryArg(RequestArg):
-    """\
-    Extract a view keyword argument from ``request.query``.
-
-    Example::
-
-        @app.route('/add', GET, a=QueryArg(int), b=QueryArg(int))
-        def view(a, b):
-            return Response(['a + b = %d' % (a + b)])
-    """
-    source = RequestArg.query
-
-
-class FormArg(RequestArg):
-    """\
-    Extract a view keyword argument from ``request.form``.
-
-    Example::
-
-        @app.route('/mul', POST, a=FormArg(int), b=FormArg(int))
-        def view(a, b):
-            return Response(['a * b = %d' % (a * b)])
-
-    """
-    source = RequestArg.form
-
-
-class SessionArg(RequestArg):
-    """\
-    Extract a view keyword argument from ``request.form``.
-
-    Example::
-
-        @app.route('/mul', POST, a=FormArg(int), b=FormArg(int))
-        def view(a, b):
-            return Response(['a * b = %d' % (a * b)])
-
-    """
-    source = RequestArg.session
-
-
-class From(object):
-    """\
-    Accessors for RequestArg classes::
-
-        from fresco.routing import Route, From
-
-        Route('/blah', GET, x=From.get(), y=From.cookie())
-
-    """
-    form = FormArg
-    query = QueryArg
-    get = QueryArg
-    post = FormArg
-    cookie = CookieArg
-    session = SessionArg
