@@ -1,5 +1,6 @@
 from fresco import Route, GET, Response
 
+
 class CBV(object):
     """
     A class based view
@@ -14,10 +15,14 @@ class CBV(object):
     def __init__(self, s):
         self.s = s
 
-    def index_html(self, request):
+    def index_html(self):
         return Response([self.s])
 
-    def view_page(self, request):
+    def view_page(self):
         return Response([])
 
 
+def module_level_function():
+    """
+    A module level function
+    """
