@@ -3,6 +3,7 @@ from nose.tools import assert_equal
 from fresco import Response
 from fresco import FrescoApp, GET, POST, PUT, DELETE
 from fresco import Route, urlfor, context
+from fresco.util.wsgi import ClosingIterator
 from . import fixtures
 
 
@@ -334,6 +335,54 @@ class TestAppRequestContext(object):
             assert context.request.environ['PATH_INFO'] == '/'
             assert context.request.environ['QUERY_STRING'] == 'x=y'
 
+    def test_it_invokes_middleware(self):
+
+        def middleware(app):
+            def middleware(environ, start_response):
+                environ['sausages'] = 1
+                return app(environ, start_response)
+            return middleware
+
+        app = FrescoApp()
+        app.add_middleware(middleware)
+        with app.requestcontext() as c:
+            assert 'sausages' in c.request.environ
+
+    def test_it_closes_middleware(self):
+
+        close = Mock()
+
+        def middleware(app):
+            def middleware(environ, start_response):
+                return ClosingIterator(app(environ, start_response), close)
+            return middleware
+
+        app = FrescoApp()
+        app.add_middleware(middleware)
+        with app.requestcontext():
+            pass
+        assert close.call_count == 1
+
+    def test_it_calls_first_iteration(self):
+        """
+        Some middleware waits until the first iteration to do things, so make
+        sure we trigger this
+        """
+        from itertools import count
+        counter = count()
+
+        def middleware(app):
+            def middleware(environ, start_response):
+                iterator = app(environ, start_response)
+                for item in iterator:
+                    yield next(counter)
+            return middleware
+
+        app = FrescoApp()
+        app.add_middleware(middleware)
+        with app.requestcontext():
+            assert next(counter) == 1
+
 
 class TestResponseExceptions(object):
 
