@@ -52,6 +52,14 @@ class TestRequestProperties(object):
         with context(SCRIPT_NAME='/foo', PATH_INFO='/bar') as c:
             assert_equal(c.request.path, '/foo/bar')
 
+    def test_query_decodes_unicode(self):
+        with context('/?q=%C3%A0') as c:
+            assert_equal(c.request.query['q'], b'\xc3\xa0'.decode('utf8'))
+
+    def test_form_decodes_unicode(self):
+        with context('/?q=%C3%A0') as c:
+            assert_equal(c.request.form['q'], b'\xc3\xa0'.decode('utf8'))
+
 
 class TestPathEncoding(object):
 
