@@ -7,8 +7,7 @@ from fresco import FrescoApp, GET, POST, Response
 from fresco.exceptions import NotFound
 from fresco.compat import ustring_type
 from fresco.core import urlfor
-from fresco.routing import Route, DelegateRoute, RouteCollection, \
-    RouteKwarg, CookieArg, SessionArg, FormArg, QueryArg, routefor
+from fresco.routing import Route, DelegateRoute, RouteCollection, routefor
 from . import fixtures
 
 
@@ -104,93 +103,6 @@ class TestPredicates(object):
         assert t.get('/', check_status=False).response.status_code == 404
 
 
-class TestRouteKwargs(object):
-
-    def test_routekwarg_configured(self):
-
-        A = RouteKwarg()
-        route = Route('/', GET, lambda r: None, x=A)
-        assert A.route is route
-        assert A.name is 'x'
-
-    def test_routekwarg_value_passed(self):
-
-        view = Mock()
-        routekwarg = Mock(spec=RouteKwarg)
-        routekwarg.return_value = 'xyzzy'
-
-        app = FrescoApp()
-        app.route('/', GET, view, x=routekwarg)
-        with app.requestcontext('/') as c:
-            app.view()
-            routekwarg.assert_called_with(c.request)
-            view.assert_called_with(x='xyzzy')
-
-    def test_queryarg_value_passed(self):
-        view = Mock()
-        app = FrescoApp()
-        app.route('/', GET, view, x=QueryArg())
-        with app.requestcontext('/?x=foo'):
-            app.view()
-            view.assert_called_with(x='foo')
-
-    def test_formarg_value_passed(self):
-        view = Mock()
-        app = FrescoApp()
-        app.route('/', GET, view, x=FormArg())
-        with app.requestcontext('/?x=foo'):
-            app.view()
-            view.assert_called_with(x='foo')
-
-    def test_sessionarg_value_passed(self):
-        view = Mock()
-        app = FrescoApp()
-        app.route('/', GET, view, x=SessionArg())
-        with app.requestcontext('/?x=foo') as c:
-            c.request.environ[c.request.SESSION_ENV_KEY] = {'x': 'foo'}
-            app.view()
-            view.assert_called_with(x='foo')
-
-    def test_cookiearg_value_passed(self):
-        view = Mock()
-        app = FrescoApp()
-        app.route('/', GET, view, x=CookieArg())
-        with app.requestcontext('/', HTTP_COOKIE='x=foo'):
-            app.view()
-            view.assert_called_with(x='foo')
-
-    def test_cookiearg_listvalue_passed(self):
-        view = Mock()
-        app = FrescoApp()
-        app.route('/', GET, view, x=CookieArg([str]))
-        with app.requestcontext('/', HTTP_COOKIE='x=foo;x=bar'):
-            app.view()
-            view.assert_called_with(x=['foo', 'bar'])
-
-    def test_requestarg_value_converted(self):
-        view = Mock()
-        app = FrescoApp()
-        app.route('/', GET, view, x=FormArg(float))
-        with app.requestcontext('/?x=0'):
-            app.view()
-            view.assert_called_with(x=0.0)
-
-    def test_requestarg_default_value(self):
-        view = Mock()
-        app = FrescoApp()
-        app.route('/', GET, view, x=FormArg(default='d'))
-        with app.requestcontext('/'):
-            app.view()
-            view.assert_called_with(x='d')
-
-    def test_requestarg_returns_badrequest(self):
-        view = Mock()
-        app = FrescoApp()
-        app.route('/', GET, view, x=FormArg())
-        with app.requestcontext('/'):
-            assert 'Bad Request' in app.view().status
-
-
 class TestRouteNames(object):
 
     def test_name_present_in_route_keys(self):
