@@ -5,7 +5,7 @@ from tempfile import NamedTemporaryFile
 
 
 @contextmanager
-def atomic_writer(path, mode=0644):
+def atomic_writer(path, mode=0o644):
     """
     Write to path in an atomic operation. Auto creates any directories leading
     up to ``path``
