@@ -93,7 +93,7 @@ def parse_querystring(data, charset=None, strict=False, keep_blank_values=True,
     Return ``(key, value)`` pairs from the given querystring::
 
         >>> list(parse_querystring('green%20eggs=ham;me=sam+i+am'))
-        [('green eggs', u'ham'), (u'me', u'sam i am')]
+        [(u'green eggs', u'ham'), (u'me', u'sam i am')]
 
     :param data: The query string to parse.
     :param charset: Character encoding used to decode values. If not specified,
